@@ -1,6 +1,6 @@
 #ifndef lint
-/*static char yysccsid[] = "from: @(#)yaccpar	1.9 (Berkeley) 02/21/93";*/
-static char yyrcsid[]
+/*static char conf_sccsid[] = "from: @(#)yaccpar	1.9 (Berkeley) 02/21/93";*/
+static char conf_rcsid[]
 #if __GNUC__ >= 2
   __attribute__ ((unused))
 #endif /* __GNUC__ >= 2 */
@@ -10,24 +10,24 @@ static char yyrcsid[]
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
-#define YYLEX yylex()
+#define YYLEX conf_lex()
 #define YYEMPTY -1
-#define yyclearin (yychar=(YYEMPTY))
-#define yyerrok (yyerrflag=0)
-#define YYRECOVERING() (yyerrflag!=0)
-#define YYPREFIX "yy"
-#line 45 "../../amd/conf_parse.y"
+#define conf_clearin (conf_char=(YYEMPTY))
+#define conf_errok (conf_errflag=0)
+#define YYRECOVERING() (conf_errflag!=0)
+#define YYPREFIX "conf_"
+#line 45 "conf_parse.y"
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif /* HAVE_CONFIG_H */
 #include <am_defs.h>
 #include <amd.h>
 
-extern char *yytext;
-extern int ayylineno;
-extern int yylex(void);
+extern char *conf_text;
+extern int aconf_lineno;
+extern int conf_lex(void);
 
-static int yyerror(const char *s);
+static int conf_error(const char *s);
 static int retval;
 static char *header_section = NULL; /* start with no header section */
 
@@ -36,14 +36,14 @@ static char *header_section = NULL; /* start with no header section */
 #define PARSE_DEBUG 0
 
 #if PARSE_DEBUG
-# define dprintf(f,s) fprintf(stderr, (f), ayylineno, (s))
+# define dprintf(f,s) fprintf(stderr, (f), aconf_lineno, (s))
 # define amu_return(v)
 #else /* not PARSE_DEBUG */
 # define dprintf(f,s)
 # define amu_return(v) return((v))
 #endif /* not PARSE_DEBUG */
 
-#line 73 "../../amd/conf_parse.y"
+#line 73 "conf_parse.y"
 #ifndef YYSTYPE_DEFINED
 #define YYSTYPE_DEFINED
 typedef union {
@@ -60,27 +60,27 @@ char *strtype;
 #define QUOTED_NONWSEQ_STRING 263
 #define YYERRCODE 256
 #if defined(__cplusplus) || defined(__STDC__)
-const short yylhs[] =
+const short conf_lhs[] =
 #else
-short yylhs[] =
+short conf_lhs[] =
 #endif
 	{                                        -1,
     2,    0,    4,    0,    1,    1,    3,    3,    5,    6,
     7,    7,    8,    8,    8,    8,
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const short yylen[] =
+const short conf_len[] =
 #else
-short yylen[] =
+short conf_len[] =
 #endif
 	{                                         2,
     0,    3,    0,    2,    1,    2,    1,    2,    2,    4,
     1,    2,    4,    4,    4,    1,
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const short yydefred[] =
+const short conf_defred[] =
 #else
-short yydefred[] =
+short conf_defred[] =
 #endif
 	{                                      0,
     0,    0,    0,    0,    0,    0,    4,    0,    0,    6,
@@ -88,44 +88,44 @@ short yydefred[] =
    10,    0,    0,    0,   13,   14,   15,
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const short yydgoto[] =
+const short conf_dgoto[] =
 #else
-short yydgoto[] =
+short conf_dgoto[] =
 #endif
 	{                                       1,
     5,    2,    7,    3,    8,    9,   16,   17,
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const short yysindex[] =
+const short conf_sindex[] =
 #else
-short yysindex[] =
+short conf_sindex[] =
 #endif
 	{                                      0,
     0, -256, -246, -256, -246, -249,    0, -246, -251,    0,
     0, -245,    0,    0, -244,    0, -251, -243, -255,    0,
     0, -242, -241, -240,    0,    0,    0,};
 #if defined(__cplusplus) || defined(__STDC__)
-const short yyrindex[] =
+const short conf_rindex[] =
 #else
-short yyrindex[] =
+short conf_rindex[] =
 #endif
 	{                                   -257,
     0,    0,    0, -236,    0,    0,    0,   14,    0,    0,
     0,    0,    0,    0,    0,    0,    1,    0,    0,    0,
     0,    0,    0,    0,    0,    0,    0,};
 #if defined(__cplusplus) || defined(__STDC__)
-const short yygindex[] =
+const short conf_gindex[] =
 #else
-short yygindex[] =
+short conf_gindex[] =
 #endif
 	{                                      0,
    12,    0,   -3,    0,    0,    0,    5,    0,
 };
 #define YYTABLESIZE 258
 #if defined(__cplusplus) || defined(__STDC__)
-const short yytable[] =
+const short conf_table[] =
 #else
-short yytable[] =
+short conf_table[] =
 #endif
 	{                                       3,
    11,   11,    1,    4,   13,   22,   23,   24,   14,   15,
@@ -156,9 +156,9 @@ short yytable[] =
     0,    0,    0,    0,    0,    0,    0,   11,
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const short yycheck[] =
+const short conf_check[] =
 #else
-short yycheck[] =
+short conf_check[] =
 #endif
 	{                                     257,
     0,    5,  260,  260,    8,  261,  262,  263,  260,  261,
@@ -195,9 +195,9 @@ short yycheck[] =
 #define YYMAXTOKEN 263
 #if YYDEBUG
 #if defined(__cplusplus) || defined(__STDC__)
-const char * const yyname[] =
+const char * const conf_name[] =
 #else
-char *yyname[] =
+char *conf_name[] =
 #endif
 	{
 "end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
@@ -210,9 +210,9 @@ char *yyname[] =
 "EQUAL","NEWLINE","NONWS_STRING","NONWSEQ_STRING","QUOTED_NONWSEQ_STRING",
 };
 #if defined(__cplusplus) || defined(__STDC__)
-const char * const yyrule[] =
+const char * const conf_rule[] =
 #else
-char *yyrule[] =
+char *conf_rule[] =
 #endif
 	{"$accept : file",
 "$$1 :",
@@ -245,25 +245,25 @@ char *yyrule[] =
 #endif
 #endif
 #define YYINITSTACKSIZE 200
-int yydebug;
-int yynerrs;
-int yyerrflag;
-int yychar;
-short *yyssp;
-YYSTYPE *yyvsp;
-YYSTYPE yyval;
-YYSTYPE yylval;
-short *yyss;
-short *yysslim;
-YYSTYPE *yyvs;
-int yystacksize;
-#line 149 "../../amd/conf_parse.y"
+int conf_debug;
+int conf_nerrs;
+int conf_errflag;
+int conf_char;
+short *conf_ssp;
+YYSTYPE *conf_vsp;
+YYSTYPE conf_val;
+YYSTYPE conf_lval;
+short *conf_ss;
+short *conf_sslim;
+YYSTYPE *conf_vs;
+int conf_stacksize;
+#line 149 "conf_parse.y"
 
 static int
-yyerror(const char *s)
+conf_error(const char *s)
 {
   fprintf(stderr, "AMDCONF: %s on line %d (section %s)\n",
-	  s, ayylineno,
+	  s, aconf_lineno,
 	  (header_section ? header_section : "null"));
   exit(1);
   return 1;	/* to full compilers that insist on a return statement */
@@ -271,316 +271,316 @@ yyerror(const char *s)
 #line 220 "conf_parse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 #if defined(__cplusplus) || defined(__STDC__)
-static int yygrowstack(void)
+static int conf_growstack(void)
 #else
-static int yygrowstack()
+static int conf_growstack()
 #endif
 {
     int newsize, i;
     short *newss;
     YYSTYPE *newvs;
 
-    if ((newsize = yystacksize) == 0)
+    if ((newsize = conf_stacksize) == 0)
         newsize = YYINITSTACKSIZE;
     else if (newsize >= YYMAXDEPTH)
         return -1;
     else if ((newsize *= 2) > YYMAXDEPTH)
         newsize = YYMAXDEPTH;
-    i = yyssp - yyss;
-    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
+    i = conf_ssp - conf_ss;
+    newss = conf_ss ? (short *)realloc(conf_ss, newsize * sizeof *newss) :
       (short *)malloc(newsize * sizeof *newss);
     if (newss == NULL)
         goto bail;
-    yyss = newss;
-    yyssp = newss + i;
-    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
+    conf_ss = newss;
+    conf_ssp = newss + i;
+    newvs = conf_vs ? (YYSTYPE *)realloc(conf_vs, newsize * sizeof *newvs) :
       (YYSTYPE *)malloc(newsize * sizeof *newvs);
     if (newvs == NULL)
         goto bail;
-    yyvs = newvs;
-    yyvsp = newvs + i;
-    yystacksize = newsize;
-    yysslim = yyss + newsize - 1;
+    conf_vs = newvs;
+    conf_vsp = newvs + i;
+    conf_stacksize = newsize;
+    conf_sslim = conf_ss + newsize - 1;
     return 0;
 bail:
-    if (yyss)
-            free(yyss);
-    if (yyvs)
-            free(yyvs);
-    yyss = yyssp = NULL;
-    yyvs = yyvsp = NULL;
-    yystacksize = 0;
+    if (conf_ss)
+            free(conf_ss);
+    if (conf_vs)
+            free(conf_vs);
+    conf_ss = conf_ssp = NULL;
+    conf_vs = conf_vsp = NULL;
+    conf_stacksize = 0;
     return -1;
 }
 
-#define YYABORT goto yyabort
-#define YYREJECT goto yyabort
-#define YYACCEPT goto yyaccept
-#define YYERROR goto yyerrlab
+#define YYABORT goto conf_abort
+#define YYREJECT goto conf_abort
+#define YYACCEPT goto conf_accept
+#define YYERROR goto conf_errlab
 int
 #if defined(__cplusplus) || defined(__STDC__)
-yyparse(void)
+conf_parse(void)
 #else
-yyparse()
+conf_parse()
 #endif
 {
-    int yym, yyn, yystate;
+    int conf_m, conf_n, conf_state;
 #if YYDEBUG
 #if defined(__cplusplus) || defined(__STDC__)
-    const char *yys;
+    const char *conf_s;
 #else /* !(defined(__cplusplus) || defined(__STDC__)) */
-    char *yys;
+    char *conf_s;
 #endif /* !(defined(__cplusplus) || defined(__STDC__)) */
 
-    if ((yys = getenv("YYDEBUG")))
+    if ((conf_s = getenv("YYDEBUG")))
     {
-        yyn = *yys;
-        if (yyn >= '0' && yyn <= '9')
-            yydebug = yyn - '0';
+        conf_n = *conf_s;
+        if (conf_n >= '0' && conf_n <= '9')
+            conf_debug = conf_n - '0';
     }
 #endif /* YYDEBUG */
 
-    yynerrs = 0;
-    yyerrflag = 0;
-    yychar = (-1);
+    conf_nerrs = 0;
+    conf_errflag = 0;
+    conf_char = (-1);
 
-    if (yyss == NULL && yygrowstack()) goto yyoverflow;
-    yyssp = yyss;
-    yyvsp = yyvs;
-    *yyssp = yystate = 0;
+    if (conf_ss == NULL && conf_growstack()) goto conf_overflow;
+    conf_ssp = conf_ss;
+    conf_vsp = conf_vs;
+    *conf_ssp = conf_state = 0;
 
-yyloop:
-    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
-    if (yychar < 0)
+conf_loop:
+    if ((conf_n = conf_defred[conf_state]) != 0) goto conf_reduce;
+    if (conf_char < 0)
     {
-        if ((yychar = yylex()) < 0) yychar = 0;
+        if ((conf_char = conf_lex()) < 0) conf_char = 0;
 #if YYDEBUG
-        if (yydebug)
+        if (conf_debug)
         {
-            yys = 0;
-            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
-            if (!yys) yys = "illegal-symbol";
+            conf_s = 0;
+            if (conf_char <= YYMAXTOKEN) conf_s = conf_name[conf_char];
+            if (!conf_s) conf_s = "illegal-symbol";
             printf("%sdebug: state %d, reading %d (%s)\n",
-                    YYPREFIX, yystate, yychar, yys);
+                    YYPREFIX, conf_state, conf_char, conf_s);
         }
 #endif
     }
-    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
-            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
+    if ((conf_n = conf_sindex[conf_state]) && (conf_n += conf_char) >= 0 &&
+            conf_n <= YYTABLESIZE && conf_check[conf_n] == conf_char)
     {
 #if YYDEBUG
-        if (yydebug)
+        if (conf_debug)
             printf("%sdebug: state %d, shifting to state %d\n",
-                    YYPREFIX, yystate, yytable[yyn]);
+                    YYPREFIX, conf_state, conf_table[conf_n]);
 #endif
-        if (yyssp >= yysslim && yygrowstack())
+        if (conf_ssp >= conf_sslim && conf_growstack())
         {
-            goto yyoverflow;
+            goto conf_overflow;
         }
-        *++yyssp = yystate = yytable[yyn];
-        *++yyvsp = yylval;
-        yychar = (-1);
-        if (yyerrflag > 0)  --yyerrflag;
-        goto yyloop;
+        *++conf_ssp = conf_state = conf_table[conf_n];
+        *++conf_vsp = conf_lval;
+        conf_char = (-1);
+        if (conf_errflag > 0)  --conf_errflag;
+        goto conf_loop;
     }
-    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
-            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
+    if ((conf_n = conf_rindex[conf_state]) && (conf_n += conf_char) >= 0 &&
+            conf_n <= YYTABLESIZE && conf_check[conf_n] == conf_char)
     {
-        yyn = yytable[yyn];
-        goto yyreduce;
+        conf_n = conf_table[conf_n];
+        goto conf_reduce;
     }
-    if (yyerrflag) goto yyinrecovery;
+    if (conf_errflag) goto conf_inrecovery;
 #if defined(lint) || defined(__GNUC__)
-    goto yynewerror;
+    goto conf_newerror;
 #endif
-yynewerror:
-    yyerror("syntax error");
+conf_newerror:
+    conf_error("syntax error");
 #if defined(lint) || defined(__GNUC__)
-    goto yyerrlab;
+    goto conf_errlab;
 #endif
-yyerrlab:
-    ++yynerrs;
-yyinrecovery:
-    if (yyerrflag < 3)
+conf_errlab:
+    ++conf_nerrs;
+conf_inrecovery:
+    if (conf_errflag < 3)
     {
-        yyerrflag = 3;
+        conf_errflag = 3;
         for (;;)
         {
-            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
-                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
+            if ((conf_n = conf_sindex[*conf_ssp]) && (conf_n += YYERRCODE) >= 0 &&
+                    conf_n <= YYTABLESIZE && conf_check[conf_n] == YYERRCODE)
             {
 #if YYDEBUG
-                if (yydebug)
+                if (conf_debug)
                     printf("%sdebug: state %d, error recovery shifting\
- to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
+ to state %d\n", YYPREFIX, *conf_ssp, conf_table[conf_n]);
 #endif
-                if (yyssp >= yysslim && yygrowstack())
+                if (conf_ssp >= conf_sslim && conf_growstack())
                 {
-                    goto yyoverflow;
+                    goto conf_overflow;
                 }
-                *++yyssp = yystate = yytable[yyn];
-                *++yyvsp = yylval;
-                goto yyloop;
+                *++conf_ssp = conf_state = conf_table[conf_n];
+                *++conf_vsp = conf_lval;
+                goto conf_loop;
             }
             else
             {
 #if YYDEBUG
-                if (yydebug)
+                if (conf_debug)
                     printf("%sdebug: error recovery discarding state %d\n",
-                            YYPREFIX, *yyssp);
+                            YYPREFIX, *conf_ssp);
 #endif
-                if (yyssp <= yyss) goto yyabort;
-                --yyssp;
-                --yyvsp;
+                if (conf_ssp <= conf_ss) goto conf_abort;
+                --conf_ssp;
+                --conf_vsp;
             }
         }
     }
     else
     {
-        if (yychar == 0) goto yyabort;
+        if (conf_char == 0) goto conf_abort;
 #if YYDEBUG
-        if (yydebug)
+        if (conf_debug)
         {
-            yys = 0;
-            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
-            if (!yys) yys = "illegal-symbol";
+            conf_s = 0;
+            if (conf_char <= YYMAXTOKEN) conf_s = conf_name[conf_char];
+            if (!conf_s) conf_s = "illegal-symbol";
             printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
-                    YYPREFIX, yystate, yychar, yys);
+                    YYPREFIX, conf_state, conf_char, conf_s);
         }
 #endif
-        yychar = (-1);
-        goto yyloop;
+        conf_char = (-1);
+        goto conf_loop;
     }
-yyreduce:
+conf_reduce:
 #if YYDEBUG
-    if (yydebug)
+    if (conf_debug)
         printf("%sdebug: state %d, reducing by rule %d (%s)\n",
-                YYPREFIX, yystate, yyn, yyrule[yyn]);
+                YYPREFIX, conf_state, conf_n, conf_rule[conf_n]);
 #endif
-    yym = yylen[yyn];
-    yyval = yyvsp[1-yym];
-    switch (yyn)
+    conf_m = conf_len[conf_n];
+    conf_val = conf_vsp[1-conf_m];
+    switch (conf_n)
     {
 case 1:
-#line 87 "../../amd/conf_parse.y"
-{ yydebug = PARSE_DEBUG; }
+#line 87 "conf_parse.y"
+{ conf_debug = PARSE_DEBUG; }
 break;
 case 3:
-#line 88 "../../amd/conf_parse.y"
-{ yydebug = PARSE_DEBUG; }
+#line 88 "conf_parse.y"
+{ conf_debug = PARSE_DEBUG; }
 break;
 case 10:
-#line 103 "../../amd/conf_parse.y"
+#line 103 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr, "sec_header1 = \"%s\"\n", yyvsp[-2].strtype);
-		  header_section = yyvsp[-2].strtype;
+		  if (conf_debug)
+		    fprintf(stderr, "sec_header1 = \"%s\"\n", conf_vsp[-2].strtype);
+		  header_section = conf_vsp[-2].strtype;
 		}
 break;
 case 13:
-#line 115 "../../amd/conf_parse.y"
+#line 115 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		}
 break;
 case 14:
-#line 125 "../../amd/conf_parse.y"
+#line 125 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		}
 break;
 case 15:
-#line 135 "../../amd/conf_parse.y"
+#line 135 "conf_parse.y"
 {
-		  if (yydebug)
-		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
-		  retval = set_conf_kv(header_section, yyvsp[-3].strtype, yyvsp[-1].strtype);
+		  if (conf_debug)
+		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
 		  if (retval != 0) {
-		    yyerror("syntax error");
+		    conf_error("syntax error");
 		    YYABORT;
 		  }
 		}
 break;
 #line 465 "conf_parse.c"
     }
-    yyssp -= yym;
-    yystate = *yyssp;
-    yyvsp -= yym;
-    yym = yylhs[yyn];
-    if (yystate == 0 && yym == 0)
+    conf_ssp -= conf_m;
+    conf_state = *conf_ssp;
+    conf_vsp -= conf_m;
+    conf_m = conf_lhs[conf_n];
+    if (conf_state == 0 && conf_m == 0)
     {
 #if YYDEBUG
-        if (yydebug)
+        if (conf_debug)
             printf("%sdebug: after reduction, shifting from state 0 to\
  state %d\n", YYPREFIX, YYFINAL);
 #endif
-        yystate = YYFINAL;
-        *++yyssp = YYFINAL;
-        *++yyvsp = yyval;
-        if (yychar < 0)
+        conf_state = YYFINAL;
+        *++conf_ssp = YYFINAL;
+        *++conf_vsp = conf_val;
+        if (conf_char < 0)
         {
-            if ((yychar = yylex()) < 0) yychar = 0;
+            if ((conf_char = conf_lex()) < 0) conf_char = 0;
 #if YYDEBUG
-            if (yydebug)
+            if (conf_debug)
             {
-                yys = 0;
-                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
-                if (!yys) yys = "illegal-symbol";
+                conf_s = 0;
+                if (conf_char <= YYMAXTOKEN) conf_s = conf_name[conf_char];
+                if (!conf_s) conf_s = "illegal-symbol";
                 printf("%sdebug: state %d, reading %d (%s)\n",
-                        YYPREFIX, YYFINAL, yychar, yys);
+                        YYPREFIX, YYFINAL, conf_char, conf_s);
             }
 #endif
         }
-        if (yychar == 0) goto yyaccept;
-        goto yyloop;
+        if (conf_char == 0) goto conf_accept;
+        goto conf_loop;
     }
-    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
-            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
-        yystate = yytable[yyn];
+    if ((conf_n = conf_gindex[conf_m]) && (conf_n += conf_state) >= 0 &&
+            conf_n <= YYTABLESIZE && conf_check[conf_n] == conf_state)
+        conf_state = conf_table[conf_n];
     else
-        yystate = yydgoto[yym];
+        conf_state = conf_dgoto[conf_m];
 #if YYDEBUG
-    if (yydebug)
+    if (conf_debug)
         printf("%sdebug: after reduction, shifting from state %d \
-to state %d\n", YYPREFIX, *yyssp, yystate);
+to state %d\n", YYPREFIX, *conf_ssp, conf_state);
 #endif
-    if (yyssp >= yysslim && yygrowstack())
+    if (conf_ssp >= conf_sslim && conf_growstack())
     {
-        goto yyoverflow;
+        goto conf_overflow;
     }
-    *++yyssp = yystate;
-    *++yyvsp = yyval;
-    goto yyloop;
-yyoverflow:
-    yyerror("yacc stack overflow");
-yyabort:
-    if (yyss)
-            free(yyss);
-    if (yyvs)
-            free(yyvs);
-    yyss = yyssp = NULL;
-    yyvs = yyvsp = NULL;
-    yystacksize = 0;
+    *++conf_ssp = conf_state;
+    *++conf_vsp = conf_val;
+    goto conf_loop;
+conf_overflow:
+    conf_error("yacc stack overflow");
+conf_abort:
+    if (conf_ss)
+            free(conf_ss);
+    if (conf_vs)
+            free(conf_vs);
+    conf_ss = conf_ssp = NULL;
+    conf_vs = conf_vsp = NULL;
+    conf_stacksize = 0;
     return (1);
-yyaccept:
-    if (yyss)
-            free(yyss);
-    if (yyvs)
-            free(yyvs);
-    yyss = yyssp = NULL;
-    yyvs = yyvsp = NULL;
-    yystacksize = 0;
+conf_accept:
+    if (conf_ss)
+            free(conf_ss);
+    if (conf_vs)
+            free(conf_vs);
+    conf_ss = conf_ssp = NULL;
+    conf_vs = conf_vsp = NULL;
+    conf_stacksize = 0;
     return (0);
 }
