@@ -11,4 +11,4 @@ typedef union {
 char *strtype;
 } YYSTYPE;
 #endif /* YYSTYPE_DEFINED */
-extern YYSTYPE yylval;
+extern YYSTYPE conf_lval;
