@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1-rc2"
-#define PACKAGE_STRING "am-utils 6.1-rc2"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd3.6"
+#define HOST_OS "openbsd3.7"
 #define HOST_OS_NAME "openbsd3"
-#define HOST_OS_VERSION "3.6"
+#define HOST_OS_VERSION "3.7"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-openbsd36.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-openbsd37.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Fri Apr 29 10:22:33 EDT 2005"
+#define CONFIG_DATE "Thu May 11 11:28:24 EDT 2006"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1-rc2"
-#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1-rc2"
+#define VERSION "6.2a2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -30,10 +30,12 @@
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "3.6"
+#ifdef __cplusplus
+#include <stdlib.h>
+#endif
+#define HOST_HEADER_VERSION "3.7"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -80,11 +82,13 @@
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
-#define HAVE_STRCHR 1
+#define HAVE_STATFS 1
 #define HAVE_STRCASECMP 1
+#define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
@@ -101,6 +105,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
@@ -149,7 +154,6 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
-#define HAVE_LIMITS_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
@@ -221,6 +225,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_openbsd.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -230,6 +235,7 @@
 #define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
+#define rpcvers_t unsigned long
 #define HAVE_FHANDLE 1
 #define MTYPE_TYPE char *
 #define MTYPE_PRINTF_TYPE "%s"
@@ -239,6 +245,7 @@
 #define SVC_IN_ARG_TYPE caddr_t
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -255,8 +262,10 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
 #define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
@@ -271,7 +280,10 @@
 #define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
+#define HAVE_NFS_ARGS_T_ADDRLEN 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_NFS_ARGS_T_SOTYPE 1
@@ -280,7 +292,10 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_DBM_OPEN 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
@@ -328,6 +343,7 @@
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNTTAB_TYPE_UMAPFS "umapfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
 #define MNT2_GEN_OPT_NOSUID 0x8
@@ -359,5 +375,8 @@
 #define MNT2_CDFS_OPT_EXTATT 0x4
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
+#define MNT2_PCFS_OPT_LONGNAME 0x2
+#define MNT2_PCFS_OPT_NOWIN95 0x4
+#define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
